@@ -93,8 +93,8 @@ end
 
 function InternalAPI.reinit_self!(
         cache::GeneralizedFirstOrderAlgorithmCache, args...; p = cache.p, u0 = cache.u,
-        alias_u0::Bool = hasproperty(cache, :alias_u0) ? cache.alias_u0 : false, 
-        maxiters = hasproperty(cache, :maxiters) ? cache.maxiters : 1000, 
+        alias_u0::Bool = hasproperty(cache, :alias_u0) ? cache.alias_u0 : false,
+        maxiters = hasproperty(cache, :maxiters) ? cache.maxiters : 1000,
         maxtime = hasproperty(cache, :maxtime) ? cache.maxtime : nothing, kwargs...
 )
     Utils.reinit_common!(cache, u0, p, alias_u0)
@@ -124,9 +124,9 @@ function SciMLBase.__init(
         prob::AbstractNonlinearProblem, alg::GeneralizedFirstOrderAlgorithm, args...;
         stats = NLStats(0, 0, 0, 0, 0), alias_u0 = false, maxiters = 1000,
         abstol = nothing, reltol = nothing, maxtime = nothing,
-        termination_condition = nothing, internalnorm = L2_NORM,
+        termination_condition = nothing, internalnorm::IN = L2_NORM,
         linsolve_kwargs = (;), initializealg = NonlinearSolveBase.NonlinearSolveDefaultInit(), kwargs...
-)
+) where {IN}
     @set! alg.autodiff = NonlinearSolveBase.select_jacobian_autodiff(prob, alg.autodiff)
     provided_jvp_autodiff = alg.jvp_autodiff !== nothing
     @set! alg.jvp_autodiff = if !provided_jvp_autodiff && alg.autodiff !== nothing &&
@@ -266,7 +266,7 @@ function InternalAPI.step!(
             end
             # In the 2nd call the `new_jacobian` is guaranteed to be `true`.
             cache.make_new_jacobian = true
-            InternalAPI.step!(cache; recompute_jacobian = true, kwargs...)
+            InternalAPI.step!(cache; recompute_jacobian = true, cache.kwargs...)
             return
         end
     end
